# Yeast Pathway Kit Assembly Report

Yeast pathway kit assembly 2014-05-14 13:12:23:

pYPK0_TEF1tp_SsXYL1_TDH3tp_SsXYL2_PGItp_ScXKS1_FBA1tp_ScTAL1_PDC1tp_pw (plan)

List of all PCR primers needed

pYPK0_TEF1tp_SsXYL1_TDH3tp (plan)

> - pYPKa_Z_TEF1tp (plan)
> - pYPKa_A_SsXYL1 (plan)
> - pYPKa_E_TDH3tp (plan)

pYPK0_TDH3tp_SsXYL2_PGItp (plan)

> - pYPKa_Z_TDH3tp (plan)
> - pYPKa_A_SsXYL2 (plan)
> - pYPKa_E_PGItp (plan)

pYPK0_PGItp_ScXKS1_FBA1tp (plan)

> - pYPKa_Z_PGItp (plan)
> - pYPKa_A_ScXKS1 (plan)
> - pYPKa_E_FBA1tp (plan)

pYPK0_FBA1tp_ScTAL1_PDC1tp (plan)

> - pYPKa_Z_FBA1tp (plan)
> - pYPKa_A_ScTAL1 (plan)
> - pYPKa_E_PDC1tp (plan)